//$Id: graffiti-prop.h,v 1.3 2001/08/19 15:02:33 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_GRAFFITI_PROP_H
#define GUIKACHU_FORM_EDITOR_GRAFFITI_PROP_H

#include <string>
#include <iostream>

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class GraffitiProperties;
	}
    }
}

#include "graffiti.h"

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class GraffitiProperties
	    {
		Gtk::Widget *property_editor;
		
	    public:
		GraffitiProperties (Widgets::Graffiti *res);
		~GraffitiProperties ();
		Gtk::Widget *get_editor ();
	    };
	}
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_GRAFFITI_PROP_H */
